@@ -1,4 +1,5 @@
 import functools
+import inspect
 import time
 from collections import deque
 from contextvars import ContextVar
@@ -45,11 +46,11 @@ class Frame:
             if acc.status is ACTIVE:
                 acc.varset(element, varname, category, value)
 
-    def get(self, varname, key, category):
+    def get(self, varname, key, category, tentative):
         rval = ABSENT
         for element, acc in self.getters[varname]:
             if acc.status is ACTIVE:
-                tmp = acc.varget(element, varname, category)
+                tmp = acc.varget(element, varname, category, tentative)
                 if tmp is not ABSENT:
                     rval = tmp
         return rval
@@ -273,12 +274,13 @@ class SetterAccumulator(ImmediateAccumulator):
 
 
 class GetterAccumulator(ImmediateAccumulator):
-    def varget(self, element, varname, category):
+    def varget(self, element, varname, category, tentative):
         if not check_element(element, varname, category):
             return ABSENT
         cap = Capture(element)
         self.captures[element.capture] = cap
         cap.names.append(varname)
+        cap.set(varname, tentative)
         rval = self.run()
         del self.captures[element.capture]
         return rval
@@ -458,7 +460,7 @@ def interact(sym, key, category, __self__, value):
                 return choose([value, from_state], name=sym)
 
         if sym in fr.getters:
-            fr_value = fr.get(sym, key, category)
+            fr_value = fr.get(sym, key, category, value)
         else:
             fr_value = ABSENT
         if (
@@ -763,6 +765,7 @@ class PteraFunction(Selfless):
         partial_args=(),
     ):
         super().__init__(fn, state)
+        self.isgenerator = inspect.isgeneratorfunction(self.fn)
         self.overlay = overlay or Overlay()
         self.return_object = return_object
         self.origin = origin or self
@@ -842,14 +845,26 @@ class PteraFunction(Selfless):
         else:
             return self.clone(partial_args=self.partial_args + (obj,))
 
+    def _run_attachments(self):
+        interact("#time", None, None, self, time.time())
+        if self.attachments:
+            for k, v in self.attachments.items():
+                interact(f"#{k}", None, None, self, v)
+
+    def __gcall__(self, *args, **kwargs):
+        with self.overlay as _:
+            with proceed(self):
+                self._run_attachments()
+                yield from super().__call__(*self.partial_args, *args, **kwargs)
+
     def __call__(self, *args, **kwargs):
         self.ensure_state()
+        if self.isgenerator:
+            return self.__gcall__(*args, **kwargs)
+
         with self.overlay as callres:
             with proceed(self):
-                interact("#time", None, None, self, time.time())
-                if self.attachments:
-                    for k, v in self.attachments.items():
-                        interact(f"#{k}", None, None, self, v)
+                self._run_attachments()
                 rval = super().__call__(*self.partial_args, *args, **kwargs)
                 callres["0"] = callres["value"] = rval
 
