@@ -74,19 +74,10 @@ def make_resolver(*namespaces):
 class Probe(SourceProxy):
     """Observable which generates a stream of values from program variables.
 
-    Example:
-
-    >>> def f(x):
-    ...     a = x * x
-    ...     return a
-
-    >>> probe = Probe("f > a")
-    >>> probe["a"].print()
-    >>> f(4)  # Prints 16
+    Probes should be created with `ptera.probing` or `ptera.global_probe`.
 
     Arguments:
-        selector: A selector string describing the variables to probe.
-        auto_activate: Whether to activate this probe on creation (default: True)
+        selectors: The selector strings describing the variables to probe (at least one).
         raw: Defaults to False. If True, produce a stream of Capture objects that
             contain extra information about the capture. Mostly relevant for
             advanced selectors such as "f > $x:@Parameter" which captures the value
@@ -95,27 +86,23 @@ class Probe(SourceProxy):
             Capture object associated to x.
     """
 
-    def __init__(
-        self,
-        selector=None,
-        auto_activate=True,
-        raw=False,
-        _obs=None,
-        _root=None,
-    ):
+    def __init__(self, *selectors, raw=False, _obs=None, _root=None):
+        if not selectors and _obs is None:
+            raise TypeError("Probe() takes at least one selector argument.")
+
         super().__init__(_obs=_obs, _root=_root)
 
-        if selector is not None:
-            self._selector = select(selector, env_wrapper=make_resolver)
+        if selectors:
+            self._selectors = [
+                select(selector, env_wrapper=make_resolver)
+                for selector in selectors
+            ]
             self._patterns = dict_to_pattern_list(
-                {self._selector: {"value": self._emit}}
+                {sel: {"value": self._emit} for sel in self._selectors}
             )
             self._raw = raw
             self._activated = False
 
-            if auto_activate:
-                self.__enter__()
-
     def override(self, setter=lambda x: x):
         """Override the value of the focus variable using a setter function.
 
@@ -239,7 +226,7 @@ class Probe(SourceProxy):
         global_probes.remove(self)
 
 
-def probing(selector, *, raw=False):
+def probing(*selectors, raw=False):
     """Probe that can be used as a context manager.
 
     Example:
@@ -252,13 +239,36 @@ def probing(selector, *, raw=False):
     ...     f(4)  # Prints {"a": 16}
 
     Arguments:
-        selector: The selector string describing the variables to probe.
+        selectors: The selector strings describing the variables to probe (at least one).
         do: A function to execute on each data point.
         format: A format string (implies do=print)
         raw: Defaults to False. If True, produce a stream of Capture objects that
             contain extra information about the capture.
     """
-    return Probe(selector, auto_activate=False, raw=raw)
+    return Probe(*selectors, raw=raw)
+
+
+def global_probe(*selectors, raw=False):
+    """Set a probe globally.
+
+    Example:
+
+    >>> def f(x):
+    ...     a = x * x
+    ...     return a
+
+    >>> probe = global_probe("f > a")
+    >>> probe["a"].print()
+    >>> f(4)  # Prints 16
+
+    Arguments:
+        selectors: The selector strings describing the variables to probe (at least one).
+        raw: Defaults to False. If True, produce a stream of Capture objects that
+            contain extra information about the capture.
+    """
+    prb = Probe(*selectors, raw=raw)
+    prb.__enter__()
+    return prb
 
 
 @atexit.register
