@@ -126,6 +126,11 @@ class ExternalVariableCollector(NodeVisitor):
             self.provenance[node.id] = "body"
             self.assigned.add(node.id)
 
+    def visit_ExceptHandler(self, node):
+        if node.name is not None:
+            self.provenance[node.name] = "body"
+            self.assigned.add(node.name)
+
     def visit_arg(self, node):
         if node.lineno in self.comments:
             self.vardoc[node.arg] = self.comments[node.lineno]
@@ -355,6 +360,24 @@ class PteraTransformer(NodeTransformer):
             node,
         )
 
+    def visit_ExceptHandler(self, node):
+        if node.name is None:
+            new_body = []
+        else:
+            target = ast.copy_location(
+                ast.Name(id=node.name, ctx=ast.Store()), node
+            )
+            new_body = self.generate_interactions(target)
+        new_body.extend(self.visit_body(node.body))
+        return ast.copy_location(
+            ast.ExceptHandler(
+                name=node.name,
+                type=self.visit(node.type),
+                body=new_body,
+            ),
+            node,
+        )
+
     def visit_Return(self, node):
         new_value = ast.Call(
             func=ast.Name(id="__ptera_interact", ctx=ast.Load()),
